<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name>AppMgmtDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="1303"/>
        <source>Manage External Applications</source>
        <translation>Управление внешними приложениями</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1315"/>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1317"/>
        <source>Application path and arguments</source>
        <translation>Путь к приложению и аргументы</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1323"/>
        <source>Choose</source>
        <translation>Выбрать</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1327"/>
        <source>Add manually</source>
        <translation>Добавить вручную</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1331"/>
        <source>Remove</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1338"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1378"/>
        <source>Choose Application</source>
        <translation>Выбрать приложение</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1390"/>
        <source>New Application</source>
        <translation>Новое приложение</translation>
    </message>
</context>
<context>
    <name>ColorsDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="1008"/>
        <source>Colors</source>
        <translation>Цвета</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1014"/>
        <source>Reset</source>
        <translation>Сбросить</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1019"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1027"/>
        <source>Hue</source>
        <translation>Оттенок</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1028"/>
        <source>Saturation</source>
        <translation>Насыщенность</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1029"/>
        <source>Lightness</source>
        <translation>Яркость</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1038"/>
        <source>Colorize</source>
        <translation>Раскрасить</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1042"/>
        <location filename="../dialogs.cpp" line="1046"/>
        <location filename="../dialogs.cpp" line="1050"/>
        <source>Negative</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1069"/>
        <location filename="../dialogs.cpp" line="1135"/>
        <source>Red</source>
        <translation>Красный</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1074"/>
        <location filename="../dialogs.cpp" line="1143"/>
        <source>Green</source>
        <translation>Зелёный</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1079"/>
        <location filename="../dialogs.cpp" line="1151"/>
        <source>Blue</source>
        <translation>Синий</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1096"/>
        <source>Hue and Saturation</source>
        <translation>Оттенок и насыщенность</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1102"/>
        <source>Affected Channels</source>
        <translation>Задействованные каналы</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1106"/>
        <source>Brightness</source>
        <translation>Яркость</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1107"/>
        <source>Contrast</source>
        <translation>Контрастность</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1131"/>
        <source>Brightness and Contrast</source>
        <translation>Яркость и контрастность</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1171"/>
        <source>Color Balance</source>
        <translation>Цветовой баланс</translation>
    </message>
</context>
<context>
    <name>CopyMoveToDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="1407"/>
        <source>Move to...</source>
        <translation>Переместить в...</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1410"/>
        <source>Copy to...</source>
        <translation>Копировать в...</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1438"/>
        <source>Browse...</source>
        <translation>Обзор...</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1440"/>
        <source>Remove</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1447"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1452"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1463"/>
        <location filename="../dialogs.cpp" line="1489"/>
        <source>Destination:</source>
        <translation>Целевая папка:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1529"/>
        <source>Choose Folder</source>
        <translation>Выбрать папку</translation>
    </message>
</context>
<context>
    <name>CpMvDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="28"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="113"/>
        <location filename="../dialogs.cpp" line="141"/>
        <source>Copying &quot;%1&quot; to &quot;%2&quot;.</source>
        <translation>Копирование &quot;%1&quot; в &quot;%2&quot;.</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="113"/>
        <location filename="../dialogs.cpp" line="142"/>
        <source>Moving &quot;%1&quot; to &quot;%2&quot;.</source>
        <translation>Перемещение &quot;%1&quot; в &quot;%2&quot;.</translation>
    </message>
</context>
<context>
    <name>CropDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="688"/>
        <source>Cropping</source>
        <translation>Обрезка</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="696"/>
        <source>Reset</source>
        <translation>Сбросить</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="699"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="737"/>
        <source>Top</source>
        <translation>Сверху</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="735"/>
        <source>Left</source>
        <translation>Слева</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="736"/>
        <source>Right</source>
        <translation>Справа</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="738"/>
        <source>Bottom</source>
        <translation>Снизу</translation>
    </message>
</context>
<context>
    <name>ImageTags</name>
    <message>
        <location filename="../tags.cpp" line="59"/>
        <source>Tag</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="63"/>
        <source>Untag</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="73"/>
        <source>Clear Filters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="66"/>
        <source>New Tag</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="36"/>
        <source>Image Tags</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="37"/>
        <source>Filter</source>
        <translation type="unfinished">Фильтр</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="70"/>
        <source>Remove Tag</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="77"/>
        <source>Negate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="179"/>
        <location filename="../tags.cpp" line="482"/>
        <location filename="../tags.cpp" line="491"/>
        <source>Error</source>
        <translation type="unfinished">Ошибка</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="179"/>
        <source>Failed to save tags to </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="381"/>
        <source>Tagging </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="384"/>
        <source>Untagging </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="473"/>
        <source>Add a new tag</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="474"/>
        <source>Enter new tag name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="482"/>
        <source>No name entered</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="491"/>
        <source>Tag </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="491"/>
        <source> already exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="508"/>
        <source>Remove selected tags(s)?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="509"/>
        <source>Remove tag</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="514"/>
        <source>Yes</source>
        <translation type="unfinished">Да</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="515"/>
        <source>Cancel</source>
        <translation type="unfinished">Отмена</translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <location filename="../imageview.cpp" line="626"/>
        <source>Clipboard</source>
        <translation>Буфер обмена</translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="780"/>
        <source>Selection size: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="828"/>
        <source>No selection</source>
        <translation>Нет выделения</translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="828"/>
        <source>Hold down the Ctrl key and select a region using the mouse.</source>
        <translation>Зажмите клавишу Ctrl и выделите область изображения с помощью мыши.</translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="975"/>
        <location filename="../imageview.cpp" line="1021"/>
        <source>Failed to save image.</source>
        <translation>Не удалось сохранить изображение.</translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="988"/>
        <source>Failed to save Exif metadata.</source>
        <translation>Не удалось сохранить метаданные Exif.</translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="993"/>
        <location filename="../imageview.cpp" line="1034"/>
        <source>Image saved.</source>
        <translation>Изображение сохранено.</translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="958"/>
        <source>Saving...</source>
        <translation>Сохранение...</translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="975"/>
        <location filename="../imageview.cpp" line="988"/>
        <location filename="../imageview.cpp" line="1021"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="1005"/>
        <source>Save image as</source>
        <translation>Сохранить изображение как</translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="1007"/>
        <source>Images</source>
        <translation>Изображения</translation>
    </message>
</context>
<context>
    <name>InfoView</name>
    <message>
        <location filename="../infoview.cpp" line="40"/>
        <source>Copy</source>
        <translation>Копировать</translation>
    </message>
</context>
<context>
    <name>Phototonic</name>
    <message>
        <location filename="../mainwindow.cpp" line="117"/>
        <source>Image Info</source>
        <translation>Информация о изображении</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="200"/>
        <location filename="../mainwindow.cpp" line="201"/>
        <source>Zoom</source>
        <translation>Зум</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="223"/>
        <location filename="../mainwindow.cpp" line="224"/>
        <source>Transform</source>
        <translation>Преобразовать</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="276"/>
        <source>Top</source>
        <translation>Вверх</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="281"/>
        <source>Bottom</source>
        <translation>Вниз</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="286"/>
        <source>Close Image</source>
        <translation>Закрыть изображение</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="290"/>
        <source>Full Screen</source>
        <translation>Во весь экран</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="295"/>
        <source>Preferences</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="300"/>
        <source>Exit</source>
        <translation>Выйти</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="304"/>
        <source>Enlarge Thumbnails</source>
        <translation>Увеличить эскизы</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="311"/>
        <source>Shrink Thumbnails</source>
        <translation>Уменьшить эскизы</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="318"/>
        <source>Cut</source>
        <translation>Вырезать</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="324"/>
        <source>Copy</source>
        <translation>Копировать</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1459"/>
        <location filename="../mainwindow.cpp" line="1468"/>
        <location filename="../mainwindow.cpp" line="1525"/>
        <location filename="../mainwindow.cpp" line="1534"/>
        <source>Rotation %1°</source>
        <translation>Поворот %1°</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2232"/>
        <source>Docks and Toolbars</source>
        <translation>Доки и панели инструментов</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="212"/>
        <location filename="../mainwindow.cpp" line="213"/>
        <source>Mirroring</source>
        <translation>Зеркалирование</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="338"/>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="343"/>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="347"/>
        <source>Save As</source>
        <translation>Сохранить как</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="356"/>
        <location filename="../mainwindow.cpp" line="3151"/>
        <source>Rename</source>
        <translation>Переименовать</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="360"/>
        <source>Select All</source>
        <translation>Выбрать всё</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="364"/>
        <location filename="../mainwindow.cpp" line="1069"/>
        <source>About</source>
        <translation>О программе</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="370"/>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="372"/>
        <source>Time</source>
        <translation>Время</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="374"/>
        <source>Size</source>
        <translation>Размер</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="376"/>
        <source>Type</source>
        <translation>Тип</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="378"/>
        <source>Reverse</source>
        <translation>Обратный порядок</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="401"/>
        <source>Show Hidden Files</source>
        <translation>Показать скрытые файлы</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="407"/>
        <source>Show Labels</source>
        <translation>Показать метки</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="414"/>
        <source>Small Icons</source>
        <translation>Маленькие значки</translation>
    </message>
    <message>
        <source>Hide Docks Title Bar</source>
        <translation type="vanished">Спрятать заголовки доков</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="432"/>
        <source>Classic Thumbs</source>
        <translation>Классические эскизы</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="434"/>
        <source>Compact</source>
        <translation>Компактный вид</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="436"/>
        <source>Squarish</source>
        <translation>Прямоугольниками</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="448"/>
        <source>Reload</source>
        <translation>Обновить</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="453"/>
        <source>Include Sub-folders</source>
        <translation>Включая подпапки</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="459"/>
        <source>Paste Here</source>
        <translation>Вставить здесь</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="465"/>
        <source>New Folder</source>
        <translation>Новая папка</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="470"/>
        <source>Back</source>
        <translation>Назад</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="476"/>
        <source>Forward</source>
        <translation>Вперёд</translation>
    </message>
    <message>
        <source>Up</source>
        <translation type="vanished">Вверх</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="487"/>
        <source>Home</source>
        <translation>Домой</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="492"/>
        <location filename="../mainwindow.cpp" line="2717"/>
        <source>Slide Show</source>
        <translation>Слайд-шоу</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="497"/>
        <source>Next</source>
        <translation>Следующее</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="502"/>
        <source>Previous</source>
        <translation>Предыдущее</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="507"/>
        <source>First</source>
        <translation>Первое</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="512"/>
        <source>Last</source>
        <translation>Последнее</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="517"/>
        <source>Random</source>
        <translation>Случайное</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="521"/>
        <source>Open</source>
        <translation>Открыть</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="531"/>
        <location filename="../mainwindow.cpp" line="532"/>
        <source>Open With...</source>
        <translation>Открыть с помощью...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="602"/>
        <source>Scale Image</source>
        <translation>Масштабировать изображение</translation>
    </message>
    <message>
        <source>Contributors / Code:</source>
        <translation type="vanished">Участники / код:</translation>
    </message>
    <message>
        <source>Contributors / Translations:</source>
        <translation type="vanished">Участники / переводчики:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1104"/>
        <source>Failed to start external application.</source>
        <translation>Не удалось запустить внешнее приложение.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1128"/>
        <source>Invalid selection.</source>
        <translation>Неправильное выделение.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1330"/>
        <source>Failed to copy or move image.</source>
        <translation>Не удалось копировать или переместить изображение.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1390"/>
        <location filename="../mainwindow.cpp" line="1408"/>
        <source>Zoom %1%</source>
        <translation>Зум %1%</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1675"/>
        <location filename="../mainwindow.cpp" line="3027"/>
        <source>Copied</source>
        <translation>Скопировано</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1675"/>
        <location filename="../mainwindow.cpp" line="3027"/>
        <source>Moved</source>
        <translation>Переместить</translation>
    </message>
    <message numerus="yes">
        <location filename="../mainwindow.cpp" line="1676"/>
        <location filename="../mainwindow.cpp" line="1870"/>
        <location filename="../mainwindow.cpp" line="3028"/>
        <source>%n image(s)</source>
        <translation>
            <numerusform>%n изображение</numerusform>
            <numerusform>%n изображения</numerusform>
            <numerusform>%n изображений</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1739"/>
        <source>Permanently delete</source>
        <translation>Навсегда удалить</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1744"/>
        <location filename="../mainwindow.cpp" line="1811"/>
        <location filename="../mainwindow.cpp" line="3289"/>
        <source>Yes</source>
        <translation>Да</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1745"/>
        <location filename="../mainwindow.cpp" line="1812"/>
        <location filename="../mainwindow.cpp" line="3290"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1842"/>
        <source>Failed to delete image.</source>
        <translation>Не удалось удалить изображение.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1870"/>
        <source>Deleted</source>
        <translation>Удалено</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1902"/>
        <source>Invalid Path:</source>
        <translation>Неправильный путь:</translation>
    </message>
    <message>
        <source>Failed to open file &quot;%1&quot;: file not found.</source>
        <translation type="vanished">Не удалось открыть файл &quot;%1&quot;: файл не найден.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2745"/>
        <source>Stop Slide Show</source>
        <translation>Остановит слайд-шоу</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3140"/>
        <source>Duplicate images in %1</source>
        <translation>Повторяющиеся изображения в %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3222"/>
        <source>Enter a new name for &quot;%1&quot;:</source>
        <translation>Введите новое имя для &quot;%1&quot;:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3235"/>
        <source>No name entered.</source>
        <translation>Имя не было введено.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3265"/>
        <source>Failed to rename image.</source>
        <translation>Не удалось переименовать изображение.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3281"/>
        <source>Permanently delete &quot;%1&quot; and all of its contents?</source>
        <translation>Навсегда удалить &quot;%1&quot; и всё её содержиое?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3304"/>
        <source>Failed to delete folder.</source>
        <translation>Не удалось удалить папку.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3308"/>
        <source>Removed &quot;%1&quot;</source>
        <translation>Удалена &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3349"/>
        <source>Failed to create new folder.</source>
        <translation>Не удалось создать новую папку.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3354"/>
        <source>Created &quot;%1&quot;</source>
        <translation>Создана &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3395"/>
        <source>Cannot perform action with temporary image.</source>
        <translation>Невозможно выполнить действие с временным изображением.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="535"/>
        <source>Manage External Applications</source>
        <translation>Управление внешними приложениями</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="548"/>
        <source>Zoom Out</source>
        <translation>Отдалить</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="553"/>
        <source>Zoom In</source>
        <translation>Приблизить</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="558"/>
        <source>Reset Zoom</source>
        <translation>Сбросить масштаб</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="563"/>
        <location filename="../mainwindow.cpp" line="1424"/>
        <source>Original Size</source>
        <translation>Исходный размер</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="568"/>
        <source>Keep Zoom</source>
        <translation>Сохранить масштаб</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="573"/>
        <source>Rotate 90 degree CCW</source>
        <translation>Повернуть на 90° против часовой стрелки</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="578"/>
        <source>Rotate 90 degree CW</source>
        <translation>Повернуть на 90° по часовой стрелке</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="583"/>
        <source>Flip Horizontally</source>
        <translation>Отразить по горизонтали</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="588"/>
        <source>Flip Vertically</source>
        <translation>Отразить по вертикали</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="593"/>
        <source>Cropping</source>
        <translation>Обрезка</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="607"/>
        <source>Rotate 1 degree CCW</source>
        <translation>Повернуть на 1° против часовой стрелки</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="611"/>
        <source>Rotate 1 degree CW</source>
        <translation>Повернуть на 1° по часовой стрелке</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="615"/>
        <source>Colors</source>
        <translation>Цвета</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="626"/>
        <source>Disable</source>
        <translation>Запретить</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="628"/>
        <source>Dual</source>
        <translation>Дважды</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="630"/>
        <source>Triple</source>
        <translation>Трижды</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="632"/>
        <source>Dual Vertical</source>
        <translation>Дважды по вертикали</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="634"/>
        <source>Quad</source>
        <translation>Четырежды</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="654"/>
        <source>Move Left</source>
        <translation>Сдвинуть влево</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="657"/>
        <source>Move Right</source>
        <translation>Сдвинуть вправо</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="660"/>
        <source>Move Up</source>
        <translation>Сдвинуть вверх</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="663"/>
        <source>Move Down</source>
        <translation>Сдвинуть вниз</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="667"/>
        <source>Invert Selection</source>
        <translation>Инвертировать выделение</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="771"/>
        <source>Edit</source>
        <translation>Правка</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="252"/>
        <location filename="../mainwindow.cpp" line="253"/>
        <location filename="../mainwindow.cpp" line="801"/>
        <source>View</source>
        <translation>Вид</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="720"/>
        <source>Sort By</source>
        <translation>Упорядочить по</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="781"/>
        <source>Navigation</source>
        <translation>Навигация</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="808"/>
        <source>Filter</source>
        <translation>Фильтр</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="871"/>
        <source>Initializing...</source>
        <translation>Инициализация...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="885"/>
        <source>File System</source>
        <translation>Файловая система</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1044"/>
        <source>&lt;p&gt;Image viewer and organizer&lt;/p&gt;</source>
        <translation>&lt;p&gt;Просмотрщик и органайзер изображений&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1046"/>
        <source>Home page</source>
        <translation>Домашняя страница</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1047"/>
        <source>Bug reports</source>
        <translation>Сообщения об ошибках</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="681"/>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="689"/>
        <source>&amp;Edit</source>
        <translation>&amp;Правка</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="705"/>
        <source>&amp;Go</source>
        <translation>&amp;Переход</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="714"/>
        <source>&amp;View</source>
        <translation>&amp;Вид</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="747"/>
        <source>&amp;Help</source>
        <translation>&amp;Справка</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2983"/>
        <source>Can not move or copy images to this folder.</source>
        <translation>Невозможно переместить или копировать изображения в эту папку.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2989"/>
        <source>Destination folder is same as source.</source>
        <translation>Папка назначения совпадает с исходной.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2997"/>
        <source>Move &quot;%1&quot; to &quot;%2&quot;?</source>
        <translation>Переместить &quot;%1&quot; в &quot;%2&quot;?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3006"/>
        <source>Failed to move folder.</source>
        <translation>Не удалось переместить папку.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3108"/>
        <source>Failed to open folder:</source>
        <translation>Не удалось открыть папку:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3164"/>
        <location filename="../mainwindow.cpp" line="3338"/>
        <source>Invalid name entered.</source>
        <translation>Введено неправильное имя.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3175"/>
        <source>Failed to rename folder.</source>
        <translation>Не удалось переименовать папку.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3208"/>
        <source>Invalid selection</source>
        <translation>Неправильное выделение</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1104"/>
        <location filename="../mainwindow.cpp" line="1330"/>
        <location filename="../mainwindow.cpp" line="1638"/>
        <location filename="../mainwindow.cpp" line="1651"/>
        <location filename="../mainwindow.cpp" line="1761"/>
        <location filename="../mainwindow.cpp" line="1842"/>
        <location filename="../mainwindow.cpp" line="1902"/>
        <location filename="../mainwindow.cpp" line="2703"/>
        <location filename="../mainwindow.cpp" line="2983"/>
        <location filename="../mainwindow.cpp" line="2989"/>
        <location filename="../mainwindow.cpp" line="3006"/>
        <location filename="../mainwindow.cpp" line="3108"/>
        <location filename="../mainwindow.cpp" line="3164"/>
        <location filename="../mainwindow.cpp" line="3175"/>
        <location filename="../mainwindow.cpp" line="3235"/>
        <location filename="../mainwindow.cpp" line="3265"/>
        <location filename="../mainwindow.cpp" line="3304"/>
        <location filename="../mainwindow.cpp" line="3338"/>
        <location filename="../mainwindow.cpp" line="3349"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1638"/>
        <source>Can not copy or move to </source>
        <translation>Невозможно копировать или переместить в </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1740"/>
        <source>Delete image</source>
        <translation>Удалить изображение</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1761"/>
        <source>Failed to delete image</source>
        <translation>Не удалось удалить изображение</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1507"/>
        <location filename="../mainwindow.cpp" line="1798"/>
        <source>No selection</source>
        <translation>Нет выделения</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1807"/>
        <source>Delete images</source>
        <translation>Удалить изображения</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1806"/>
        <source>Permanently delete selected images?</source>
        <translation>Навсегда удалить выделенные изображения?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="330"/>
        <source>Copy to...</source>
        <translation>Копировать в...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="334"/>
        <source>Move to...</source>
        <translation>Переместить в...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="351"/>
        <source>Copy Image Data</source>
        <translation>Копировать изображение в буфер</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="353"/>
        <source>Paste Image Data</source>
        <translation>Вставить изображение из буфера</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="420"/>
        <source>Hide Dock Title Bars</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="426"/>
        <source>Show Toolbar</source>
        <translation>Показать панель инструментов</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="482"/>
        <source>Go Up</source>
        <translation type="unfinished">Вверх</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="526"/>
        <source>Load Clipboard</source>
        <translation>Вставить изображение из буфера</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="539"/>
        <source>Add Bookmark</source>
        <translation>Добавить закладку</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="544"/>
        <source>Remove Bookmark</source>
        <translation>Удалить закладку</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="598"/>
        <source>Crop to Selection</source>
        <translation>Обрезать в выделение</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="620"/>
        <source>Find Duplicate Images</source>
        <translation>Найти повторяющиеся изображения</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="649"/>
        <source>Lock Transformations</source>
        <translation>Зафиксировать преобразования</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="671"/>
        <source>Filter by Name</source>
        <translation>Фильтровать по имени</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="674"/>
        <source>Set Path</source>
        <translation>Установить путь</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="743"/>
        <source>&amp;Tools</source>
        <translation>&amp;Инструменты</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="825"/>
        <source>Image</source>
        <translation>Изображение</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="922"/>
        <source>Bookmarks</source>
        <translation>Закладки</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="945"/>
        <source>Tags</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1384"/>
        <source>Minimum zoom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1402"/>
        <source>Maximum zoom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1416"/>
        <source>Zoom Reset</source>
        <translation>Сбросить масштаб</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1431"/>
        <source>Zoom Locked</source>
        <translation>Масштаб зафиксирован</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1433"/>
        <source>Zoom Unlocked</source>
        <translation>Масштаб разблокирован</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1442"/>
        <source>Transformations Locked</source>
        <translation>Преобразования зафиксированы</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1447"/>
        <source>Transformations Unlocked</source>
        <translation>Преобразования разблокированы</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1475"/>
        <source>Flipped Vertically</source>
        <translation>Отражено по вертикали</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1475"/>
        <source>Unflipped Vertically</source>
        <translation>Возвращено в исходное положение по вертикали</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1482"/>
        <source>Flipped Horizontally</source>
        <translation>Отражено по горизонтали</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1482"/>
        <source>Unflipped Horizontally</source>
        <translation>Возвращено в исходное положение по горизонтали</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1578"/>
        <source>Mirroring Disabled</source>
        <translation>Зеркалирование отключено</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1585"/>
        <source>Mirroring: Dual</source>
        <translation>Зеркалирование: дважды</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1592"/>
        <source>Mirroring: Triple</source>
        <translation>Зеркалирование: трижды</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1599"/>
        <source>Mirroring: Dual Vertical</source>
        <translation>Зеркалирование: дважды по вертикали</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1606"/>
        <source>Mirroring: Quad</source>
        <translation>Зеркалирование: четырежды</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1651"/>
        <source>Can not copy or move to the same folder</source>
        <translation>Невозможно копировать или переместить в одну и ту же папку</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1758"/>
        <source>Deleted </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2216"/>
        <source>Viewer</source>
        <translation>Просмотрщик</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2554"/>
        <source>No images</source>
        <translation>Нет изображений</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2703"/>
        <source>Failed to open file &quot;%1&quot;, file not found.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2718"/>
        <source>Slide show stopped</source>
        <translation>Слайд-шоу остановлено</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2746"/>
        <source>Slide show started</source>
        <translation>Началось слайд-шоу</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2998"/>
        <source>Move folder</source>
        <translation>Переместить папку</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3008"/>
        <source>Folder moved</source>
        <translation>Папка перемещена</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3153"/>
        <source>New name:</source>
        <translation>Новое имя:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3220"/>
        <source>Rename Image</source>
        <translation>Переименовать изображение</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3285"/>
        <source>Delete folder</source>
        <translation>Удалить папку</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3326"/>
        <source>New Sub folder</source>
        <translation>Новая подпапка</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3327"/>
        <source>New folder name:</source>
        <translation>Имя новой папки:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3395"/>
        <source>Warning</source>
        <translation>Внимание</translation>
    </message>
</context>
<context>
    <name>ProgressDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="1555"/>
        <source>Cancel</source>
        <translation type="unfinished">Отмена</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Usage: phototonic [FILE or DIRECTORY]...</source>
        <translation type="vanished">Использование: phototonic [ФАЙЛ или ПАПКА]...</translation>
    </message>
</context>
<context>
    <name>ResizeDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="813"/>
        <source>Scale Image</source>
        <translation>Масштабировать изображение</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="825"/>
        <source>Scale</source>
        <translation>Масштабировать</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="829"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="845"/>
        <source>Original size:</source>
        <translation>Первоначальный размер:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="848"/>
        <source>Width:</source>
        <translation>Ширина:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="849"/>
        <source>Height:</source>
        <translation>Высота:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="850"/>
        <source>Units:</source>
        <translation>Единицы:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="852"/>
        <source>New size:</source>
        <translation>Новый размер:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="855"/>
        <source>Pixels</source>
        <translation>Пиксели</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="857"/>
        <source>Percent</source>
        <translation>Проценты</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="862"/>
        <source>Lock aspect ratio</source>
        <translation>Зафиксировать соотношение сторон</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="270"/>
        <source>Preferences</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="331"/>
        <source>Default quality when saving images:</source>
        <translation>Качество по умолчанию при сохроанении изображений:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="309"/>
        <location filename="../dialogs.cpp" line="371"/>
        <source>Background color:</source>
        <translation>Цвет фона:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="277"/>
        <location filename="../dialogs.cpp" line="294"/>
        <source>By width or height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="349"/>
        <source>Show image file name in viewer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="395"/>
        <source>Background image:</source>
        <translation>Фоновое изображение:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="414"/>
        <source>Add space between thumbnails:</source>
        <translation>Добавить пробел между эскизами:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="429"/>
        <source>Number of thumbnail pages to read ahead:</source>
        <translation>Количество страниц с эскизами загружаемыми заранее:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="452"/>
        <source>Delay between slides in seconds:</source>
        <translation>Задержка между слайдами в секундах:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="545"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="550"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="345"/>
        <source>Rotate image according to Exif orientation</source>
        <translation>Поворачивать изображение согласно ориентации EXIF</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="425"/>
        <source>Show original size of images smaller than the thumbnail size</source>
        <translation>Показывать настоящий размер изображений, которые меньше чем размер эскиза</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="438"/>
        <source>Rotate thumbnails according to Exif orientation</source>
        <translation>Поворачивать эскизы согласно ориентации EXIF</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="566"/>
        <source>Thumbnails</source>
        <translation>Эскизы</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="275"/>
        <source>Fit Large Images</source>
        <translation>Подгонять большие изображения</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="276"/>
        <location filename="../dialogs.cpp" line="293"/>
        <source>Disable</source>
        <translation>Запретить</translation>
    </message>
    <message>
        <source>By width and height</source>
        <translation type="vanished">По ширине и высоте</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="278"/>
        <location filename="../dialogs.cpp" line="295"/>
        <source>By width</source>
        <translation>По ширине</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="279"/>
        <location filename="../dialogs.cpp" line="296"/>
        <source>By height</source>
        <translation>По высоте</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="280"/>
        <location filename="../dialogs.cpp" line="297"/>
        <source>Stretch disproportionately</source>
        <translation>Вписать непропорционально</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="292"/>
        <source>Fit Small Images</source>
        <translation>Подгонять маленькие изображения</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="323"/>
        <source>Exit instead of closing, when image is loaded from command line</source>
        <translation>Выход вместо закрытия, когда изображение загружено из командной строки</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="327"/>
        <source>Wrap image list when reaching last or first image</source>
        <translation>Закольцевать список изображений при достижении последнего или первого изображения</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="341"/>
        <source>Enable GIF animation</source>
        <translation>Включить GIF-анимацию</translation>
    </message>
    <message>
        <source>Show image file name in full screen mode</source>
        <translation type="vanished">Показывать полное имя изображения в полноэкранном режиме</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="472"/>
        <source>Startup folder</source>
        <translation>Начальная папка</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="474"/>
        <source>Default, or specified by command line argument</source>
        <translation>По умолчанию, или заданная аргументом командной строки</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="475"/>
        <source>Remember last</source>
        <translation>Запомнить последнюю</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="476"/>
        <source>Specify:</source>
        <translation>Задать:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="527"/>
        <source>Delete confirmation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="531"/>
        <source>Keyboard Shortcuts</source>
        <translation>Сочетания клавиш</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="562"/>
        <source>Viewer</source>
        <translation>Просмотрщик</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="681"/>
        <source>Open File</source>
        <translation>Открыть файл</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="682"/>
        <source>Images</source>
        <translation>Изображения</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="462"/>
        <source>Show random images</source>
        <translation>Показывать случайные изображения</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="570"/>
        <source>Slide Show</source>
        <translation>Слайд-шоу</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="523"/>
        <source>Swap mouse left-click and middle-click actions</source>
        <translation>Поменять местами действия по левому и среднему щелчку мыши</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="383"/>
        <source>Label color:</source>
        <translation>Цвет имени:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="574"/>
        <source>General</source>
        <translation>Общие</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="674"/>
        <source>Choose Startup Folder</source>
        <translation>Выбрать стартовую папку</translation>
    </message>
</context>
<context>
    <name>ShortcutsTable</name>
    <message>
        <location filename="../dialogs.cpp" line="170"/>
        <source>Action</source>
        <translation>Действие</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="171"/>
        <source>Shortcut</source>
        <translation>Сочетание клавиш</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="185"/>
        <source>Delete shortcut</source>
        <translation>Удалить сочетание клавиш</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="227"/>
        <location filename="../dialogs.cpp" line="239"/>
        <source>Set shortcut</source>
        <translation>Присвоить сочетание клавиш</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="228"/>
        <source>&quot;%1&quot; is reserved for shortcuts to external applications.</source>
        <translation>&quot;%1&quot; зарезервировано для сочетаний клавиш для внешних приложений.</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="240"/>
        <source>&quot;%1&quot; is already assigned to &quot;%2&quot; action.</source>
        <translation>«%1» уже присвоено действию «%2».</translation>
    </message>
</context>
<context>
    <name>ThumbView</name>
    <message>
        <location filename="../thumbview.cpp" line="247"/>
        <source>File name</source>
        <translation>Имя файла</translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="251"/>
        <source>Location</source>
        <translation>Местоположение</translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="264"/>
        <source>Format</source>
        <translation>Формат</translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="268"/>
        <source>Resolution</source>
        <translation>Разрешение</translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="274"/>
        <source>Megapixel</source>
        <translation>Мегапикселей</translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="255"/>
        <source>Size</source>
        <translation>Размер</translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="245"/>
        <source>General</source>
        <translation>Общие</translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="259"/>
        <source>Modified</source>
        <translation>Изменён</translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="282"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message numerus="yes">
        <location filename="../thumbview.cpp" line="463"/>
        <location filename="../thumbview.cpp" line="684"/>
        <location filename="../thumbview.cpp" line="685"/>
        <source>%n image(s)</source>
        <translation>
            <numerusform>%n изображение</numerusform>
            <numerusform>%n изображения</numerusform>
            <numerusform>%n изображений</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="465"/>
        <source>No images</source>
        <translation>Нет изображений</translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="297"/>
        <source>Selected %1 of%2</source>
        <translation>Выбрано %1 из%2</translation>
    </message>
    <message numerus="yes">
        <location filename="../thumbview.cpp" line="299"/>
        <source> %n image(s)</source>
        <translatorcomment>In Russian &quot;of&quot; changes declension of a noun after number</translatorcomment>
        <translation>
            <numerusform> %n изображения</numerusform>
            <numerusform> %n изображений</numerusform>
            <numerusform> %n изображений</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="683"/>
        <source>Scanned %1, displaying %2 (%3 and %4)</source>
        <translation>Просмотрено %1, показано %2 (%3 и %4)</translation>
    </message>
    <message numerus="yes">
        <location filename="../thumbview.cpp" line="686"/>
        <source>%n original(s)</source>
        <translation>
            <numerusform>%n оригинал</numerusform>
            <numerusform>%n оригинала</numerusform>
            <numerusform>%n оригиналов</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../thumbview.cpp" line="687"/>
        <source>%n duplicate(s)</source>
        <translation>
            <numerusform>%n копия</numerusform>
            <numerusform>%n копии</numerusform>
            <numerusform>%n копий</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="582"/>
        <source>Searching duplicate images...</source>
        <translation>Поиск копий изображений...</translation>
    </message>
</context>
</TS>
